@@ -125,6 +125,8 @@ extern const unary_function_ptr * const  at_LOG;
 extern const unary_function_ptr * const  at_LQ;
 extern const unary_function_ptr * const  at_LSQ;
 extern const unary_function_ptr * const  at_LU;
+extern const unary_function_ptr * const  at_LambertW;
+extern const unary_function_ptr * const  at_LambertWs;
 extern const unary_function_ptr * const  at_Li;
 extern const unary_function_ptr * const  at_Line;
 extern const unary_function_ptr * const  at_LineHorz;
@@ -353,6 +355,7 @@ extern const unary_function_ptr * const  at_besselY;
 extern const unary_function_ptr * const  at_betad;
 extern const unary_function_ptr * const  at_betad_cdf;
 extern const unary_function_ptr * const  at_betad_icdf;
+extern const unary_function_ptr * const  at_betavariate;
 extern const unary_function_ptr * const  at_bezier;
 extern const unary_function_ptr * const  at_bezout_entiers;
 extern const unary_function_ptr * const  at_biconnected_components;
@@ -475,6 +478,7 @@ extern const unary_function_ptr * const  at_complex;
 extern const unary_function_ptr * const  at_complexroot;
 extern const unary_function_ptr * const  at_concat;
 extern const unary_function_ptr * const  at_cond;
+extern const unary_function_ptr * const  at_condensation;
 extern const unary_function_ptr * const  at_cone;
 extern const unary_function_ptr * const  at_conic;
 extern const unary_function_ptr * const  at_conj;
@@ -494,6 +498,7 @@ extern const unary_function_ptr * const  at_convexhull;
 extern const unary_function_ptr * const  at_convolution;
 extern const unary_function_ptr * const  at_coordinates;
 extern const unary_function_ptr * const  at_copy;
+extern const unary_function_ptr * const  at_copysign;
 extern const unary_function_ptr * const  at_correlation;
 extern const unary_function_ptr * const  at_cos;
 extern const unary_function_ptr * const  at_cos2sintan;
@@ -619,6 +624,7 @@ extern const unary_function_ptr * const  at_duration;
 extern const unary_function_ptr * const  at_e2r;
 extern const unary_function_ptr * const  at_ecart_type;
 extern const unary_function_ptr * const  at_ecart_type_population;
+extern const unary_function_ptr * const  at_ecm_factor;
 extern const unary_function_ptr * const  at_ecris;
 extern const unary_function_ptr * const  at_edge_connectivity;
 extern const unary_function_ptr * const  at_edges;
@@ -670,6 +676,7 @@ extern const unary_function_ptr * const  at_exp2pow;
 extern const unary_function_ptr * const  at_exp2trig;
 extern const unary_function_ptr * const  at_expexpand;
 extern const unary_function_ptr * const  at_expln2trig;
+extern const unary_function_ptr * const  at_expm1;
 extern const unary_function_ptr * const  at_exponential;
 extern const unary_function_ptr * const  at_exponential_cdf;
 extern const unary_function_ptr * const  at_exponential_icdf;
@@ -679,6 +686,7 @@ extern const unary_function_ptr * const  at_exponentiald;
 extern const unary_function_ptr * const  at_exponentiald_cdf;
 extern const unary_function_ptr * const  at_exponentiald_icdf;
 extern const unary_function_ptr * const  at_export_graph;
+extern const unary_function_ptr * const  at_expovariate;
 extern const unary_function_ptr * const  at_expr;
 extern const unary_function_ptr * const  at_extend;
 extern const unary_function_ptr * const  at_extract_measure;
@@ -704,10 +712,12 @@ extern const unary_function_ptr * const  at_fcoeff;
 extern const unary_function_ptr * const  at_fft;
 extern const unary_function_ptr * const  at_fft_mult_size;
 extern const unary_function_ptr * const  at_fieldplot;
+extern const unary_function_ptr * const  at_fill_rect;
 extern const unary_function_ptr * const  at_filled;
 extern const unary_function_ptr * const  at_filter;
 extern const unary_function_ptr * const  at_fin_enregistrement;
 extern const unary_function_ptr * const  at_find;
+extern const unary_function_ptr * const  at_find_cycles;
 extern const unary_function_ptr * const  at_findhelp;
 extern const unary_function_ptr * const  at_fisher;
 extern const unary_function_ptr * const  at_fisher_cdf;
@@ -752,6 +762,7 @@ extern const unary_function_ptr * const  at_galoisconj;
 extern const unary_function_ptr * const  at_gammad;
 extern const unary_function_ptr * const  at_gammad_cdf;
 extern const unary_function_ptr * const  at_gammad_icdf;
+extern const unary_function_ptr * const  at_gammavariate;
 extern const unary_function_ptr * const  at_gauche;
 extern const unary_function_ptr * const  at_gauss;
 extern const unary_function_ptr * const  at_gauss_seidel_linsolve;
@@ -759,6 +770,9 @@ extern const unary_function_ptr * const  at_gaussian_window;
 extern const unary_function_ptr * const  at_gaussjord;
 extern const unary_function_ptr * const  at_gaussquad;
 extern const unary_function_ptr * const  at_gbasis;
+extern const unary_function_ptr * const  at_gbasis_max_pairs;
+extern const unary_function_ptr * const  at_gbasis_reinject;
+extern const unary_function_ptr * const  at_gbasis_simult_primes;
 extern const unary_function_ptr * const  at_gcd;
 extern const unary_function_ptr * const  at_gcdex;
 extern const unary_function_ptr * const  at_genpoly;
@@ -962,6 +976,7 @@ extern const unary_function_ptr * const  at_is_inside;
 extern const unary_function_ptr * const  at_is_integer_graph;
 extern const unary_function_ptr * const  at_is_isomorphic;
 extern const unary_function_ptr * const  at_is_isosceles;
+extern const unary_function_ptr * const  at_is_matrix;
 extern const unary_function_ptr * const  at_is_network;
 extern const unary_function_ptr * const  at_is_orthogonal;
 extern const unary_function_ptr * const  at_is_parallel;
@@ -1013,6 +1028,7 @@ extern const unary_function_ptr * const  at_kneser_graph;
 extern const unary_function_ptr * const  at_kolmogorovd;
 extern const unary_function_ptr * const  at_kolmogorovt;
 extern const unary_function_ptr * const  at_kovacicsols;
+extern const unary_function_ptr * const  at_kspaths;
 extern const unary_function_ptr * const  at_l1norm;
 extern const unary_function_ptr * const  at_l2norm;
 extern const unary_function_ptr * const  at_label;
@@ -1035,6 +1051,7 @@ extern const unary_function_ptr * const  at_legendre_symbol;
 extern const unary_function_ptr * const  at_len;
 extern const unary_function_ptr * const  at_length;
 extern const unary_function_ptr * const  at_leve_crayon;
+extern const unary_function_ptr * const  at_lgamma;
 extern const unary_function_ptr * const  at_lgcd;
 extern const unary_function_ptr * const  at_lhs;
 extern const unary_function_ptr * const  at_ligne_polygonale;
@@ -1073,6 +1090,7 @@ extern const unary_function_ptr * const  at_lncollect;
 extern const unary_function_ptr * const  at_lnexpand;
 extern const unary_function_ptr * const  at_locus;
 extern const unary_function_ptr * const  at_log10;
+extern const unary_function_ptr * const  at_log1p;
 extern const unary_function_ptr * const  at_logarithmic_regression;
 extern const unary_function_ptr * const  at_logarithmic_regression_plot;
 extern const unary_function_ptr * const  at_logb;
@@ -1139,8 +1157,10 @@ extern const unary_function_ptr * const  at_modgcd;
 extern const unary_function_ptr * const  at_modgcd_cachesize;
 extern const unary_function_ptr * const  at_modp;
 extern const unary_function_ptr * const  at_mods;
+extern const unary_function_ptr * const  at_monotonic;
 extern const unary_function_ptr * const  at_montre_tortue;
 extern const unary_function_ptr * const  at_moustache;
+extern const unary_function_ptr * const  at_moving_average;
 extern const unary_function_ptr * const  at_moyal;
 extern const unary_function_ptr * const  at_moyenne;
 extern const unary_function_ptr * const  at_mpzclass_allowed;
@@ -1186,6 +1206,7 @@ extern const unary_function_ptr * const  at_normald_cdf;
 extern const unary_function_ptr * const  at_normald_icdf;
 extern const unary_function_ptr * const  at_normalize;
 extern const unary_function_ptr * const  at_normalt;
+extern const unary_function_ptr * const  at_normalvariate;
 extern const unary_function_ptr * const  at_nprimes;
 extern const unary_function_ptr * const  at_nrows;
 extern const unary_function_ptr * const  at_nuage_points;
@@ -1550,6 +1571,7 @@ extern const unary_function_ptr * const  at_sinon;
 extern const unary_function_ptr * const  at_size;
 extern const unary_function_ptr * const  at_sizes;
 extern const unary_function_ptr * const  at_skip;
+extern const unary_function_ptr * const  at_sleep;
 extern const unary_function_ptr * const  at_slope;
 extern const unary_function_ptr * const  at_slopeat;
 extern const unary_function_ptr * const  at_slopeatraw;
@@ -1571,6 +1593,7 @@ extern const unary_function_ptr * const  at_sortd;
 extern const unary_function_ptr * const  at_sorted;
 extern const unary_function_ptr * const  at_soundsec;
 extern const unary_function_ptr * const  at_spanning_tree;
+extern const unary_function_ptr * const  at_speed;
 extern const unary_function_ptr * const  at_sphere;
 extern const unary_function_ptr * const  at_spherical2rectangular;
 extern const unary_function_ptr * const  at_spline;
@@ -1692,6 +1715,7 @@ extern const unary_function_ptr * const  at_trigtan;
 extern const unary_function_ptr * const  at_trn;
 extern const unary_function_ptr * const  at_trunc;
 extern const unary_function_ptr * const  at_truncate;
+extern const unary_function_ptr * const  at_truncate_graph;
 extern const unary_function_ptr * const  at_tsimplify;
 extern const unary_function_ptr * const  at_tukey_window;
 extern const unary_function_ptr * const  at_turtle_stack;
@@ -1738,6 +1762,7 @@ extern const unary_function_ptr * const  at_weibull_icdf;
 extern const unary_function_ptr * const  at_weibulld;
 extern const unary_function_ptr * const  at_weibulld_cdf;
 extern const unary_function_ptr * const  at_weibulld_icdf;
+extern const unary_function_ptr * const  at_weibullvariate;
 extern const unary_function_ptr * const  at_weight_matrix;
 extern const unary_function_ptr * const  at_welch_window;
 extern const unary_function_ptr * const  at_whattype;
